from .main import help,check,printCourseList,waitEmptySpace,fastSelect,luckyDraw

__all__=[
    'help',
    'check',
    'printCourseList',
    'waitEmptySpace',
    'fastSelect',
    'luckyDraw'
]


__version__='0.9.0'
__license__='GPL v2'
__author__='Tiancheng Jiao'
__github__='https://github.com/jtc1246/courseSelector'
__author_email__='jtc1246@outlook.com'
__description__='Automatic course selection program for SJTU-JI'


